@@ -1,20 +1,20 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Systemd;
-$Config::Model::Systemd::VERSION = '0.232.6';
+$Config::Model::Systemd::VERSION = '0.240.1';
 use strict;
 use warnings;
 
 use 5.10.1;
 
-use Config::Model 2.096;
+use Config::Model 2.133;
 
 1;
 
@@ -32,7 +32,7 @@ Config::Model::Systemd - Editor and validator for systemd configuration files
 
 =head1 VERSION
 
-version 0.232.6
+version 0.240.1
 
 =head1 SYNOPSIS
 
@@ -40,60 +40,102 @@ version 0.232.6
 
 Requires L<App::Cme>:
 
- $ cme edit systemd-user
- $ cme check systemd-user
+Handle all user units:
 
- # cme edit systemd
- # cme check systemd
+ $ cme edit systemd-user '*'
+ $ cme check systemd-user '*'
 
-=head2 Perl program
+Handles all user units that match 'foo':
+
+ $ cme edit systemd-user foo
+ $ cme check systemd-user foo
+
+Check all root units:
+
+ # cme check systemd '*'
+
+Check all root units that match 'foo':
+
+ # cme check systemd foo
+
+Edit override file of C<foo.service>:
+
+ # cme edit systemd foo.service
+
+Handle a service file:
+
+ $ cme check systemd-service path/to/file.service
+ $ cme edit systemd-service path/to/file.service
+
+Timer and socket units are also supported:
+
+ $ cme check systemd-socket path/to/file.socket
+ $ cme check systemd-timer path/to/file.timer
+
+=head2 Perl program (experimental)
 
  use Config::Model qw/cme/;
- cme('systemd-user')->modify('socket:free-imap-tunnel Socket Accept=yes') ;
+ cme(application => 'systemd-user' backend_arg => 'free')
+    ->modify('socket:free-imap-tunnel Socket Accept=yes') ;
+
+ cme(application => 'systemd-service', config_file => 'foo.service')
+    ->modify('Unit Description="a service that does foo things"')
 
 =head1 DESCRIPTION
 
-This module provides a configuration editor for the configuration file
+This module provides a configuration editor for the configuration files
 of systemd, i.e. all files in C<~/.config/systemd/user/> or all files
 in C</etc/systemd/system/>
 
-Ok. I simplified. Actually, this module provides the configuration
+Ok. I simplified. In more details, this module provides the configuration
 models of Systemd configuration file that L<cme>, L<Config::Model> and
-L<Config::Model::TkUI> use to provide a configuration editor and
-checker.
+L<Config::Model::TkUI> use to provide a configuration editor (C<cme edit>) and
+checker (C<cme check>).
 
 =head2 invoke editor
 
 The following command loads user systemd files (from
 C<~/.config/systemd/user/> and launch a graphical editor:
 
- cme edit systemd-user
+ cme edit systemd-user foo
 
 Likewise, the following command loads system systemd configuration
-files and launch a graphical editor:
+files and launch a graphical editor to updated an override file (like
+C<systemctl edit> command):
 
- sudo cme edit systemd
+ sudo cme edit systemd foo
+
+A developer can also edit a systemd file shipped with a software:
+
+ cme edit systemd-service software-thing.service
 
 =head2 Just check systemd configuration
 
-You can also use L<cme> to run sanity checks on the configuration file:
+You can also use L<cme> to run sanity checks on systemd configuration files:
 
- cme check systemd-user
- cme check systemd
+ cme check systemd-user '*'
+ cme check systemd '*' # may take time
+ cme check systemd-service software-thing.service
 
-=head2 Use in Perl program
+=head2 Use in Perl program (experimental)
 
 As of L<Config::Model> 2.086, a L<cme/"cme(...)"> function is exported
 to modify configuration in a Perl program. For instance:
 
  use Config::Model qw/cme/; # also import cme function
  # call cme for systemd-user, modify ans save my-imap-tunnel.socket file.
- cme('systemd-user')->modify('socket:my-imap-tunnel Socket Accept=yes') ;
+ cme(
+   application => 'systemd-user',
+   backend_arg => 'my-imap-tunnel'
+ )->modify('socket:my-imap-tunnel Socket Accept=yes') ;
 
 Similarly, system Systemd files can be modified using C<systemd> application:
 
  use Config::Model qw/cme/;
- cme('systemd')->modify(...) ;
+ cme(
+   application => 'systemd',
+   backend_arg => 'foo'
+ )->modify(...) ;
 
 For more details and parameters, please see 
 L<cme|Config::Model/"cme ( ... )">,
@@ -120,7 +162,6 @@ by systemd project. This list is expected to be rather complete.
 The properties of these parameters are inferred from the description
 of the parameters and are probably less accurate. In case of errors,
 please L<log a bug|https://github.com/dod38fr/config-model-systemd/issues>.
-.
 
 =head1 TODO
 
@@ -163,7 +204,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015-2016 by Dominique Dumont.
+This software is Copyright (c) 2015-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
@@ -216,7 +257,7 @@ L<http://cpants.cpanauthors.org/dist/Config-Model-Systemd>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/C/Config-Model-Systemd>
 
